@@ -3,10 +3,11 @@
 .CacheFiles <- NULL
 .alreadyDefinedPkgs <- NULL
 .tobeDefinedPkgs <- NULL
-.numberofRequires <- NULL
+.numberofRstyleDefs <- NULL
 
 .SweaveListingOptions <- list(
 Rset = list("fancyvrb" = "true", "escapechar" = "`",
+        "extendedchars" = "false",
         "language" = "R", "basicstyle" = "{\\color{Rcolor}\\small}",
         "keywordstyle" = "{\\bf\\color{Rcolor}}",
         "commentstyle" = "{\\color{Rcommentcolor}\\ttfamily\\itshape}",
@@ -34,9 +35,10 @@ RRecomdcolor  = c(0,0.6,0.4),
 Rbcolor       = c(0,0.6,0.6),
 Routcolor     = c(0.461,0.039,0.102),
 Rcommentcolor = c(0.101,0.043,0.432),
-pkv = "2.0.2",
+pkv = "2.1.4",
 pkg = "distr",
 Keywordstyle = "{\\bf}",
+Recomd.Keywordstyle = "{\\bf\\color{RRecomdcolor}}",
 interm.Keywordstyle = "{\\bf\\color{Rbcolor}}",
 overwrite = FALSE,
 intermediate = TRUE,
@@ -48,7 +50,9 @@ addRset = TRUE,
 addRdset = TRUE,
 addRinset = TRUE,
 addRoutset = TRUE,
-addRcodeset = TRUE
+addRcodeset = TRUE,
+fileCommand = "\\def\\file#1{{\\tt #1}}",
+pkgCommand = "\\def\\pkg#1{{\\tt \"#1\"}}"
 )
 
 SweaveListingOptions <- function(...) {
